@@ -11,7 +11,7 @@ from typing import Callable, List, Optional, Tuple, Union
 import socketio
 from socketio.exceptions import ConnectionError as SioConnectionError
 
-from .config import Config
+from .config import jconfig
 from .log import logger, logger_init
 from .model import EventMsg, FriendMsg, GroupMsg
 from .plugin import PluginManager
@@ -25,7 +25,7 @@ from .typing import (
     T_GroupMsgMiddleware,
     T_GroupMsgReceiver,
 )
-from .utils import sync_run
+from .utils import check_schema, sync_run, to_address
 
 #######################
 #     socketio
@@ -56,28 +56,26 @@ class Botoy:
     # 如果在初始化实例时就导入插件, 导入插件会多执行一次插件,
     # 在初次访问时初始化更符合常理，也防止了部分潜在bug
     class LazyPluginManager:
-        def __init__(self, mgr):
-            self.mgr = mgr
-
         def __get__(self, obj, _):
+            mgr = PluginManager()
             if obj.use_plugins:
-                self.mgr.load_plugins()
-                print(self.mgr.info)
-            value = obj.__dict__["plugMgr"] = self.mgr
+                mgr.load_plugins()
+                print(mgr.info)
+            value = obj.__dict__["plugMgr"] = mgr
             return value
 
-    plugMgr: PluginManager = LazyPluginManager(PluginManager())  # type: ignore
+    plugMgr: PluginManager = LazyPluginManager()  # type: ignore
 
     def __init__(
         self,
         *,
-        qq: Union[int, List[int]] = None,
-        use_plugins: bool = False,
-        port: int = None,
-        host: str = None,
-        group_blacklist: List[int] = None,
-        friend_blacklist: List[int] = None,
-        blocked_users: List[int] = None,
+        qq: Optional[Union[int, List[int]]] = None,
+        use_plugins: Optional[bool] = False,
+        port: Optional[int] = None,
+        host: Optional[str] = None,
+        group_blacklist: Optional[List[int]] = None,
+        friend_blacklist: Optional[List[int]] = None,
+        blocked_users: Optional[List[int]] = None,
         log: bool = True,
         log_file: bool = False,
     ):
@@ -90,9 +88,13 @@ class Botoy:
             self.qq = []
         self.qq: List[int] = [int(qq) for qq in self.qq if int(qq) != 0]
 
-        self.config = Config(
-            host, port, group_blacklist, friend_blacklist, blocked_users
-        )
+        self.host = check_schema(host or jconfig.host)
+        self.port = int(port or jconfig.port)
+        self.address = to_address(self.host, self.port)
+        self.group_blacklist = group_blacklist or jconfig.group_blacklist
+        self.friend_blacklist = friend_blacklist or jconfig.friend_blacklist
+        self.blocked_users = blocked_users or jconfig.blocked_users
+        self.webhook = jconfig.webhook
 
         # 日志
         logger_init(log, log_file)
@@ -114,7 +116,7 @@ class Botoy:
         self._event_context_middlewares: List[T_EventMiddleware] = []
 
         # webhook
-        if self.config.webhook:
+        if self.webhook:
             from . import webhook  # pylint: disable=C0415
 
             flag = self.__class__.__name__.startswith("Async") and "async_" or ""
@@ -135,8 +137,8 @@ class Botoy:
 
         # 线程池 TODO: 开放该参数
         thread_works = 50
-        self.pool = WorkerPool(thread_works)
-        self._close_callbacks.append(self.pool.shutdown)
+        self._pool = WorkerPool(thread_works)
+        self._close_callbacks.append(self._pool.shutdown)
 
         # 初始化消息包接收函数
         self._friend_msg_handler = self._msg_handler_factory(FriendMsg)
@@ -155,7 +157,7 @@ class Botoy:
     def _context_handler(self, context: Union[FriendMsg, GroupMsg, EventMsg]):
         passed_context = self._context_checker(context)
         if passed_context:
-            return self.pool.submit(self._context_distributor, context)
+            return self._pool.submit(self._context_distributor, context)
         return
 
     def _context_checker(self, context: Union[FriendMsg, GroupMsg, EventMsg]):
@@ -166,16 +168,16 @@ class Botoy:
 
         if isinstance(context, FriendMsg):
             if context.FromUin in (
-                *self.config.friend_blacklist,
-                *self.config.blocked_users,
+                *self.friend_blacklist,
+                *self.blocked_users,
             ):
                 return
             middlewares = self._friend_context_middlewares
 
         elif isinstance(context, GroupMsg):
             if (
-                context.FromGroupId in self.config.group_blacklist
-                or context.FromUserId in self.config.blocked_users
+                context.FromGroupId in self.group_blacklist
+                or context.FromUserId in self.blocked_users
             ):
                 return
             middlewares = self._group_context_middlewares
@@ -190,8 +192,8 @@ class Botoy:
                 return
             context = new_context
 
-        setattr(context, "_host", self.config.host)
-        setattr(context, "_port", self.config.port)
+        setattr(context, "_host", self.host)
+        setattr(context, "_port", self.port)
 
         return context
 
@@ -202,9 +204,9 @@ class Botoy:
         for receiver in self._get_context_receivers(context):
             new_context = copy.deepcopy(context)
             if asyncio.iscoroutinefunction(receiver):
-                self.pool.submit(sync_run, receiver(new_context))  # type: ignore
+                self._pool.submit(sync_run, receiver(new_context))  # type: ignore
             else:
-                self.pool.submit(receiver, new_context)
+                self._pool.submit(receiver, new_context)
 
     def _get_context_receivers(self, context: Union[FriendMsg, GroupMsg, EventMsg]):
 
@@ -301,13 +303,13 @@ class Botoy:
     ##########################################################################
     # decorators for registering hook function when connected or disconnected
     ##########################################################################
-    def when_connected(self, func: Callable = None, *, every_time=False):
+    def when_connected(self, func: Optional[Callable] = None, *, every_time=False):
         if func is None:
             return functools.partial(self.when_connected, every_time=every_time)
         self._when_connected_do = (func, every_time)
         return None
 
-    def when_disconnected(self, func: Callable = None, *, every_time=False):
+    def when_disconnected(self, func: Optional[Callable] = None, *, every_time=False):
         if func is None:
             return functools.partial(self.when_disconnected, every_time=every_time)
         self._when_disconnected_do = (func, every_time)
@@ -316,7 +318,7 @@ class Botoy:
     ########################################################################
     # about socketio
     ########################################################################
-    def connect(self):
+    def _connect(self):
         logger.success("Connected to the server successfully!")
 
         # 连接成功执行用户定义的函数，如果有
@@ -327,9 +329,9 @@ class Botoy:
                 self._when_connected_do = None
 
         for func in self.plugMgr.when_connected_funcs:
-            self.pool.submit(func, self.qq, self.config.host, self.config.port)
+            self._pool.submit(func, self.qq, self.host, self.port)
 
-    def disconnect(self):
+    def _disconnect(self):
         logger.warning("Disconnected to the server!")
         # 断开连接后执行用户定义的函数，如果有
         if self._when_disconnected_do is not None:
@@ -338,7 +340,7 @@ class Botoy:
                 self._when_disconnected_do = None
 
         for func in self.plugMgr.when_disconnected_funcs:
-            self.pool.submit(func, self.qq, self.config.host, self.config.port)
+            self._pool.submit(func, self.qq, self.host, self.port)
 
     ########################################################################
     # 开放出来的用于多种连接方式的入口函数
@@ -366,7 +368,7 @@ class Botoy:
         self.plugMgr
         return self._event_handler(msg)
 
-    def run(self, wait: bool = True, sio: socketio.Client = None):
+    def run(self, wait: bool = True, sio: Optional[socketio.Client] = None):
         """运行
         :param wait: 是否阻塞
         """
@@ -376,8 +378,8 @@ class Botoy:
 
         sio = sio or socketio.Client()
 
-        sio.event(self.connect)
-        sio.event(self.disconnect)
+        sio.event(self._connect)
+        sio.event(self._disconnect)
         sio.on("OnGroupMsgs", self._group_msg_handler)
         sio.on("OnFriendMsgs", self._friend_msg_handler)
         sio.on("OnEvents", self._event_handler)
@@ -387,8 +389,8 @@ class Botoy:
         try:
             while True:
                 try:
-                    logger.info(f"Connecting to the server[{self.config.address}]...")
-                    sio.connect(self.config.address, transports=["websocket"])
+                    logger.info(f"Connecting to the server[{self.address}]...")
+                    sio.connect(self.address, transports=["websocket"])
                 except (SioConnectionError, ValueError):
                     current_delay = delay + (2 * random.random() - 1) / 2
                     logger.error(
@@ -406,7 +408,7 @@ class Botoy:
 
         except BaseException as e:
             sio.disconnect()
-            self.pool.shutdown(False)
+            self._pool.shutdown(False)
             if isinstance(e, KeyboardInterrupt):
                 print("\b\b\b\bbye~")
             else:
@@ -414,7 +416,7 @@ class Botoy:
 
         return sio
 
-    def run_no_wait(self, sio: socketio.Client = None):
+    def run_no_wait(self, sio: Optional[socketio.Client] = None):
         """不阻塞运行"""
         return self.run(False, sio)
 
