@@ -14,7 +14,9 @@ def with_pattern(pattern: str):
     :param pattern: 需要进行匹配的``正则表达式字符串``
     """
 
-    warnings.warn("with_pattern即将被移除，请使用in_content或on_regexp替代", SyntaxWarning, 2)
+    warnings.warn(
+        "with_pattern即将被移除，请使用on_regexp, re_match, re_findall替代", SyntaxWarning, 2
+    )
 
     def deco(func):
         def inner(ctx):
