@@ -1,7 +1,7 @@
 # pylint: disable=R0902,W0231
+import json
 from typing import Dict, List
 
-from botoy import json
 from botoy.collection import MsgTypes
 from botoy.exceptions import InvalidContextError
 from botoy.model import FriendMsg
